// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.bulkeditor.command;

import java.util.Map;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.ContributionItem;
import org.eclipse.jface.action.IContributionItem;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.CompoundContributionItem;
import org.eclipse.ui.handlers.IHandlerService;

import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationType;
import eu.etaxonomy.taxeditor.annotatedlineeditor.IEntityCreator;
import eu.etaxonomy.taxeditor.bulkeditor.BulkEditorUtil;
import eu.etaxonomy.taxeditor.bulkeditor.IBulkEditorConstants;
import eu.etaxonomy.taxeditor.bulkeditor.input.AbstractBulkEditorInput;

/**
 * <p>DynamicNewObjectMenu class.</p>
 *
 * @author n.hoffmann
 * @created 17.04.2009
 * @version 1.0
 */
public class DynamicNewObjectMenu extends CompoundContributionItem {
	private static final Logger logger = Logger
			.getLogger(DynamicNewObjectMenu.class);
	
	private IHandlerService handlerService = (IHandlerService) BulkEditorUtil.getService(IHandlerService.class);
	private Map<Object, String> classLabelPairs;
	/* (non-Javadoc)
	 * @see org.eclipse.ui.actions.CompoundContributionItem#getContributionItems()
	 */
	/** {@inheritDoc} */
	@Override
	protected IContributionItem[] getContributionItems() {
		
		classLabelPairs = getClassLabelPairs();
		
		return new IContributionItem[] {
				new ContributionItem() {
					public void fill(Menu menu, int index){
						for(final Object key : classLabelPairs.keySet()){
							createMenuItem(menu, key);
						}			
					}
				}
		};
	}

	private void createMenuItem(Menu menu, final Object key){
		MenuItem menuItem = new MenuItem(menu, -1);
		menuItem.setText(classLabelPairs.get(key));
		menuItem.addSelectionListener(new SelectionListener(){

			public void widgetDefaultSelected(SelectionEvent e) {}

			public void widgetSelected(SelectionEvent ev) {
				Event event = new Event();
				event.data = key;
				event.text = classLabelPairs.get(key);
				try {
					handlerService.executeCommand(IBulkEditorConstants.DYNAMIC_OPEN_OBJECT_ID, event);
				} catch (Exception e) {
					logger.error("Error executing command", e);
					throw new RuntimeException("Error executing command", e);
				}
			}				
		});
		
		//FIXME:3.3MC Need corresponding Details Viewer section for FieldUnit
		if(key == SpecimenOrObservationType.FieldUnit){
			menuItem.setEnabled(false);
		}
	}
	
	/**
	 * Get class label pairs from Annotated Line Editor's entity creator.
	 * @return
	 */
	private Map<Object, String> getClassLabelPairs() {
		IEditorPart editor = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage().getActiveEditor();
		if (editor != null){
			IEditorInput input = editor.getEditorInput();
			
			if(input instanceof AbstractBulkEditorInput){
				IEntityCreator<?> entityCreator = ((AbstractBulkEditorInput) input).getEntityCreator();
				return entityCreator.getKeyLabelPairs();
			}
		}
		
		return null;
	}	
}
