// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.bulkeditor.derivedunit.operation;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.api.facade.DerivedUnitFacadeNotSupportedException;
import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.SpecimenDescription;
import eu.etaxonomy.cdm.model.occurrence.DerivedUnit;
import eu.etaxonomy.taxeditor.bulkeditor.BulkEditorUtil;
import eu.etaxonomy.taxeditor.operation.AbstractPostOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;

/**
 * @author n.hoffmann
 * @created Feb 11, 2011
 * @version 1.0
 */
public class AddDerivedUnitFacadeMediaOperation extends
		AbstractPostOperation {

	public static final int DERIVED_UNIT_MEDIA = 0;
	public static final int FIELD_OBJECT_MEDIA = 1;
	
	private DerivedUnit derivedUnit;
	private int mode;
	
	/**
	 * @param label
	 * @param undoContext
	 * @param postOperationEnabled
	 */
	public AddDerivedUnitFacadeMediaOperation(String label, IUndoContext undoContext, DerivedUnit derivedUnit,
			int mode, IPostOperationEnabled postOperationEnabled) {
		super(label, undoContext, postOperationEnabled);
		
		this.derivedUnit = derivedUnit;
		this.mode = mode;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		DerivedUnitFacade facade;
		try {
			facade = DerivedUnitFacade.NewInstance(derivedUnit);

			createImageGallery(facade);
		} catch (DerivedUnitFacadeNotSupportedException e) {
			BulkEditorUtil.error(getClass(), e);
		}
		
		return postExecute(derivedUnit);
	}

	
	
	/**
	 * @param facade
	 * @return
	 */
	protected void createImageGallery(DerivedUnitFacade facade){
		if(mode == DERIVED_UNIT_MEDIA){
			facade.getDerivedUnitImageGallery(true);
		}
		else if(mode == FIELD_OBJECT_MEDIA){
			facade.getFieldObjectImageGallery(true);
		}
		else{
			throw new IllegalArgumentException("Mode not supported: " + mode);
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// TODO Auto-generated method stub
		return null;
	}

}
